from textual.events import Event


class PhaseChanged(Event):
    def __init__(self, phase: str) -> None:
        super().__init__()
        self.phase = phase


class ValuesUpdated(Event):
    def __init__(self, new_values: tuple[int, int]) -> None:
        super().__init__()
        self.focus_len, self.break_len = new_values



import sqlite3

from xdg_base_dirs import xdg_config_home

DB_PATH = f"{xdg_config_home()}/pymodoro.db"
print(DB_PATH)


class Database:
    def __init__(self):
        self.conn = sqlite3.connect(DB_PATH)
        self._init_db()

    def _init_db(self):
        with self.conn:
            self.conn.execute(
                """CREATE TABLE IF NOT EXISTS settings (
                    focus_duration INTEGER DEFAULT 25,
                    break_duration INTEGER DEFAULT 5,
                    total_time_focused_minutes INTEGER DEFAULT 0
                )"""
            )
            self.conn.execute("INSERT OR IGNORE INTO settings VALUES (25, 5, 0)")
            self.conn.commit()

    def get_db_values(self) -> tuple[int, int, int]:
        cursor = self.conn.execute("SELECT * FROM settings")
        result = cursor.fetchone()
        print(int(result[0]), int(result[1]), int(result[2]))
        return (int(result[0]), int(result[1]), int(result[2])) if result else None

    def update_setting(self, key: str, value: int):
        with self.conn:
            self.conn.execute(f"UPDATE settings SET {key} = {value}")

    def close(self):
        self.conn.close()



from textual.theme import Theme

focus_theme = Theme(
    name="focus",
    primary="#EF5350",
    secondary="#E57373",
    accent="#D32F2F",
    foreground="white",
    background="#ba4949",
    surface="#A63636",
    panel="#c15c5c",
    dark=True,
    success="#66BB6A",
    warning="#FFA726",
    error="#EF5350",
    variables={
        "block-cursor-text-style": "none",
        "footer-key-foreground": "#EF5350",
        "input-selection-background": "#E57373 35%",
    },
)

break_theme = Theme(
    name="break",
    primary="#26A69A",
    secondary="#4DB6AC",
    accent="#00796B",
    foreground="white",
    background="#38858a",
    surface="#19635C",
    panel="#4c9196",
    dark=True,
    success="#66BB6A",
    warning="#FFA726",
    error="#EF5350",
    variables={
        "block-cursor-text-style": "none",
        "footer-key-foreground": "#26A69A",
        "input-selection-background": "#4DB6AC 35%",
    },
)
